Struct FromColorUnclampedMutGuard

pub struct FromColorUnclampedMutGuard<'a, T, U>{ /* private fields */ }
A scope guard that restores the guarded colors to their original type, without clamping, when dropped.

Implementations

Source

impl<'a, T, U> FromColorUnclampedMutGuard<'a, T, U>

pub fn then_into_color_mut<C>(self) -> FromColorMutGuard<'a, C, U>
where T: FromColorMut<C>, C: FromColorMut<U> + FromColorMut<T> + ?Sized, U: FromColorMut<C>,

Convert the colors to another type and replace this guard.

The colors will not be converted back to the current color type before being restored, as opposed to when into_color_mut is called. Instead, they are restored directly to their original type.

pub fn then_into_color_unclamped_mut<C>( self, ) -> FromColorUnclampedMutGuard<'a, C, U>

Convert the colors to another type, without clamping, and replace this guard.

The colors will not be converted back to the current color type before being restored, as opposed to when into_color_unclamped_mut is called. Instead, they are restored directly to their original type.

pub fn into_clamped_guard(self) -> FromColorMutGuard<'a, T, U>
where T: FromColorMut<U>, U: FromColorMut<T>,

Replace this guard with a guard that clamps the colors after restoring.

pub fn restore(self) -> &'a mut U

Immediately restore the colors to their original type.

This happens automatically when the guard is dropped, but there may be situations where it’s better or more convenient to call restore directly.